@@ -825,3 +825,14 @@ class jac_tests(TestCaseHelper, TestCase):
         test_walker.run()
         report = test_walker.report
         self.assertEqual(len(report[0]), 4)
+
+    def test_rand_choice(self):
+        gph = graph(m_id='anon', h=mem_hook())
+        sent = sentinel(m_id='anon', h=gph._h)
+        sent.register_code(jtc.rand_choice)
+        test_walker = \
+            sent.walker_ids.get_obj_by_name('init')
+        test_walker.prime(gph)
+        test_walker.run()
+        report = test_walker.report
+        self.assertIn(report[1], report[0])
